@@ -5,7 +5,9 @@ module Control.Monad.Ghc ( Ghc, runGhc,
 
 where
 
+#if __GLASGOW_HASKELL__ < 706
 import Prelude hiding ( catch )
+#endif
 
 import Control.Monad.Trans
 import qualified Control.Monad.Trans as MTL
@@ -20,11 +22,16 @@ import qualified GhcMonad   as GHC
 import qualified HscTypes   as GHC
 #endif
 
+#if __GLASGOW_HASKELL__ >= 706
+import qualified DynFlags as GHC
+#endif
 
 newtype Ghc a = Ghc (GHC.Ghc a)
     deriving (Functor, Monad,
 #if __GLASGOW_HASKELL__ < 702
               GHC.WarnLogMonad,
+#elif __GLASGOW_HASKELL__ >= 706
+              GHC.HasDynFlags,
 #endif
               GHC.ExceptionMonad, GHC.MonadIO, GHC.GhcMonad)
 
@@ -40,7 +47,11 @@ runGhc :: Maybe FilePath -> Ghc a -> IO a
 runGhc f (Ghc m) = GHC.runGhc f m
 
 newtype GhcT m a = GhcT { unGhcT :: GHC.GhcT (MTLAdapter m) a }
-                 deriving (Functor, Monad)
+                 deriving (Functor,
+#if __GLASGOW_HASKELL__ >= 706
+                           GHC.HasDynFlags,
+#endif
+                           Monad)
 
 runGhcT :: (Functor m, MonadCatchIO m) => Maybe FilePath -> GhcT m a -> m a
 runGhcT f = unWrap . GHC.runGhcT f . unGhcT
